@@ -191,7 +191,7 @@ def _update_event_loop_policy():
             _asyncio.set_event_loop_policy(_uvloop.EventLoopPolicy())
 
 
-__version__ = "3.4.5"
+__version__ = "3.4.6"
 version_info = VersionInfo.from_str(__version__)
 
 # Filter fuzzywuzzy slow sequence matcher warning
@@ -204,12 +204,3 @@ if "--debug" not in _sys.argv:
     # Individual warnings - tracked in https://github.com/Cog-Creators/Red-DiscordBot/issues/3529
     # DeprecationWarning: an integer is required (got type float).  Implicit conversion to integers using __int__ is deprecated, and may be removed in a future version of Python.
     _warnings.filterwarnings("ignore", category=DeprecationWarning, module="importlib", lineno=219)
-    # DeprecationWarning: "@coroutine" decorator is deprecated since Python 3.8, use "async def" instead
-    #   def noop(*args, **kwargs):  # type: ignore
-    _warnings.filterwarnings("ignore", category=DeprecationWarning, module="aiohttp", lineno=107)
-    # DeprecationWarning: The loop argument is deprecated since Python 3.8, and scheduled for removal in Python 3.10.
-    #   hosts = await asyncio.shield(self._resolve_host(..
-    _warnings.filterwarnings("ignore", category=DeprecationWarning, module="aiohttp", lineno=964)
-    # DeprecationWarning: The loop argument is deprecated since Python 3.8, and scheduled for removal in Python 3.10.
-    #   self._event = asyncio.Event(loop=loop)
-    _warnings.filterwarnings("ignore", category=DeprecationWarning, module="aiohttp", lineno=21)
