@@ -604,11 +604,13 @@ class Cleanup(commands.Cog):
         else:
             await slow_deletion(to_delete)
 
-    @cleanup.command(name="spam")
+    @cleanup.command(name="duplicates", aliases=["spam"])
     @commands.guild_only()
     @checks.mod_or_permissions(manage_messages=True)
     @commands.bot_has_permissions(manage_messages=True)
-    async def cleanup_spam(self, ctx: commands.Context, number: positive_int = PositiveInt(50)):
+    async def cleanup_duplicates(
+        self, ctx: commands.Context, number: positive_int = PositiveInt(50)
+    ):
         """Deletes duplicate messages in the channel from the last X messages and keeps only one copy.
 
         Defaults to 50.
