@@ -67,7 +67,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
     def same_context(
         cls,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the message fits the described context.
@@ -104,7 +104,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
     def cancelled(
         cls,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the message is ``[p]cancel``.
@@ -133,7 +133,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
     def yes_or_no(
         cls,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the message is "yes"/"y" or "no"/"n".
@@ -176,7 +176,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
     def valid_int(
         cls,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response is an integer.
@@ -216,7 +216,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
     def valid_float(
         cls,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response is a float.
@@ -256,7 +256,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
     def positive(
         cls,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response is a positive number.
@@ -492,7 +492,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
         cls,
         value: str,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response is equal to the specified value.
@@ -522,7 +522,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
         cls,
         value: str,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response *as lowercase* is equal to the specified value.
@@ -552,7 +552,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
         cls,
         value: Union[int, float],
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response is less than the specified value.
@@ -583,7 +583,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
         cls,
         value: Union[int, float],
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response is greater than the specified value.
@@ -614,7 +614,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
         cls,
         length: int,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response's length is less than the specified length.
@@ -644,7 +644,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
         cls,
         length: int,
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response's length is greater than the specified length.
@@ -674,7 +674,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
         cls,
         collection: Sequence[str],
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response is contained in the specified collection.
@@ -718,7 +718,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
         cls,
         collection: Sequence[str],
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Same as :meth:`contained_in`, but the response is set to lowercase before matching.
@@ -759,7 +759,7 @@ class MessagePredicate(Callable[[discord.Message], bool]):
         cls,
         pattern: Union[Pattern[str], str],
         ctx: Optional[commands.Context] = None,
-        channel: Optional[discord.TextChannel] = None,
+        channel: Optional[Union[discord.TextChannel, discord.DMChannel]] = None,
         user: Optional[discord.abc.User] = None,
     ) -> "MessagePredicate":
         """Match if the response matches the specified regex pattern.
@@ -982,7 +982,7 @@ class ReactionPredicate(Callable[[discord.Reaction, discord.abc.User], bool]):
     ) -> "ReactionPredicate":
         """Match if the reaction is a tick or cross emoji.
 
-        The emojis used can are in
+        The emojis used are in
         `ReactionPredicate.YES_OR_NO_EMOJIS`.
 
         This will assign ``True`` for *yes*, or ``False`` for *no* to
